summaryrefslogtreecommitdiffstats
path: root/src/Path.cpp
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2007-01-22 05:00:29 +0000
committerDavid Robillard <d@drobilla.net>2007-01-22 05:00:29 +0000
commitaa454620bff8b6c5dcd4e0e379726307ad1918da (patch)
treefb178d760381f9492039235faa9d610bb5040f2b /src/Path.cpp
parentae90063afb7ddabcb505f8390b3b90bc7fea96ca (diff)
downloadraul-aa454620bff8b6c5dcd4e0e379726307ad1918da.tar.gz
raul-aa454620bff8b6c5dcd4e0e379726307ad1918da.tar.bz2
raul-aa454620bff8b6c5dcd4e0e379726307ad1918da.zip
Created Raul namespace.
git-svn-id: http://svn.drobilla.net/lad/raul@265 a436a847-0d15-0410-975c-d299462d15a1
Diffstat (limited to 'src/Path.cpp')
-rw-r--r--src/Path.cpp11
1 files changed, 8 insertions, 3 deletions
diff --git a/src/Path.cpp b/src/Path.cpp
index 59e18dd..07c5279 100644
--- a/src/Path.cpp
+++ b/src/Path.cpp
@@ -1,11 +1,11 @@
-/* This file is part of Ingen. Copyright (C) 2006-2007 Dave Robillard.
+/* This file is part of Raul. Copyright (C) 2007-2007 Dave Robillard.
*
* Ingen is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* Ingen is distributed in the hope that it will be useful, but WITHOUT ANY
* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
* FOR A PARTICULAR PURPOSE. See the GNU General Public License for details.
*
@@ -16,6 +16,8 @@
#include "raul/Path.h"
+namespace Raul {
+
bool
Path::is_valid(const std::basic_string<char>& path)
@@ -169,3 +171,6 @@ Path::is_parent_of(const Path& child) const
return child.is_child_of(*this);
}
+
+} // namespace Raul
+
@@ -1,11 +1,11 @@
*
- * Ingen is free software; you can redistribute it and/or modify it under the
+ * Raul is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
@@ -1,11 +1,11 @@
* version.
*
- * Ingen is distributed in the hope that it will be useful, but WITHOUT ANY
+ * Raul is distributed in the hope that it will be useful, but WITHOUT ANY
* WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
* FOR A PARTICULAR PURPOSE. See the GNU General Public License for details.